@@ -1,5 +1,6 @@
 from abc import ABC, abstractmethod
 
+from .core_enums import CheckResult
 
 class CoreCheck(): 
     def __init__(self, resource_name, context):
@@ -11,6 +12,13 @@ class CoreCheck():
         self.message = None
         self.context = context
 
-    @abstractmethod
     def scan(self):
+        try:
+            self.scan_logic()
+        except Exception as err:
+            self.result = CheckResult.ERROR
+            self.message = str(type(err)) + " " + str(err)
+
+    @abstractmethod
+    def scan_logic(self):
         pass
